@@ -9,24 +9,25 @@
 
 package org.gnu.gdk;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 /**
  *
  */
 public class Keymap extends GObject 
 {
     /****************************************
-     * BEGINNING OF GENERATED CODE
+     * BEGINNING OF JNI CODE
      ****************************************/
     native static final protected int gdk_keymap_get_type ();
-    native static final protected int gdk_keymap_get_default ();
-    native static final protected int gdk_keymap_lookup_key (int keymap, int key);
-    native static final protected boolean gdk_keymap_get_entries_for_keyval (int keymap, int 
-        keyval, int [] keys, int [] numKeys);
-    native static final protected boolean gdk_keymap_get_entries_for_keycode (int keymap, int 
-        hardwareKeycode, int [] keys, int [] keyvals, int [] numEntries);
-    native static final protected int gdk_keymap_get_direction (int keymap);
+    native static final protected Handle gdk_keymap_get_default ();
+    native static final protected int gdk_keymap_lookup_key (Handle keymap, Handle key);
+    native static final protected boolean gdk_keymap_get_entries_for_keyval (Handle keymap, int 
+        keyval, Handle [] keys);
+    native static final protected boolean gdk_keymap_get_entries_for_keycode (Handle keymap, int 
+        hardwareKeycode, Handle[] keys, int [] keyvals);
+    native static final protected int gdk_keymap_get_direction (Handle keymap);
     /****************************************
-     * END OF GENERATED CODE
+     * END OF JNI CODE
      ****************************************/
 }
 
