@@ -16,7 +16,7 @@ package org.gnu.glib;
 public class GObject {
 
 	/** holder for the raw object pointer */
-	private int handle = -1;
+    private Handle handle = null;
 
 	protected boolean eventsInitialized = false;
 
@@ -35,7 +35,7 @@ public class GObject {
 	 * @return true if both objects refer to the same object.
 	 */
 	public boolean equals( Object other ){
-		return other instanceof GObject && handle == ((GObject) other).getHandle();
+		return other instanceof GObject && handle.equals(((GObject) other).getHandle());
 	}
 	 
 	/**
@@ -45,7 +45,7 @@ public class GObject {
 	 * @return a hash code value for the object.
 	 */
 	public int hashCode() {
-		return getHandle();
+		return getHandle().hashCode();
 	}
 
 	/**
@@ -54,8 +54,8 @@ public class GObject {
 	 * 
 	 * @param handle The handle that represents a pointer to a native resource.
 	 */
-	public GObject(int handle) {
-		setHandle(handle);
+	public GObject(Handle handle) {
+                setHandle(handle);
 	}
 	
 	/** 
@@ -170,16 +170,16 @@ public class GObject {
 	 *
 	 * @return the handle value.
 	 */
-	public final int getHandle() {
+	public final Handle getHandle() {
 		return handle;
 	}
 
-	protected void setHandle(int hndl) {
+	protected void setHandle(Handle hndl) {
  		setData(hndl, "JGObject", this);
  		handle = hndl;
 	 }
 	 
-	 protected GObject retrieveGObject(int hndl) {
+	 protected GObject retrieveGObject(Handle hndl) {
 	 	return (GObject)getData(hndl, "JGObject");
 	 }
 
@@ -189,11 +189,13 @@ public class GObject {
 	    (new Exception(message)).printStackTrace();
 	 }
 
-	 protected native Object getData(int handle, String key);
-	 protected native void setData(int handle, String key, Object data);
+	 protected native Object getData(Handle handle, String key);
+	 protected native void setData(Handle handle, String key, Object data);
 
 	 native static final private void registerLogHandler();
 
+	 native static final public Handle getNullHandle();
+
 	// ------------------------------------------------------------------------
 	// static init code
 	static {
