@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.gdk.Color;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.ColorSelectionEvent;
 import org.gnu.gtk.event.ColorSelectionListener;
@@ -35,7 +36,7 @@ public class ColorSelection extends VBox {
 	/**
 	 * construct a ColorSelection from a handle to a native peer.
 	 */
-	public ColorSelection(int handle) {
+	public ColorSelection(Handle handle) {
 	    super(handle);
 	}
 
@@ -60,7 +61,7 @@ public class ColorSelection extends VBox {
 	 * @return the set colour
 	 */
 	public Color getCurrentColor() {
-	    int colorHandle = gtk_color_selection_get_current_color(getHandle());
+	    Handle colorHandle = gtk_color_selection_get_current_color(getHandle());
 	    return new Color(colorHandle);
 	}
 	
@@ -139,9 +140,11 @@ public class ColorSelection extends VBox {
 	 * Returns the previous color.
 	 */
 	public Color getPreviousColor() {
-		int [] color = new int[1];
+	    Handle color = getNullHandle();
 		gtk_color_selection_get_previous_color(getHandle(), color);
-		return new org.gnu.gdk.Color(color[0]);
+		if (null == color)
+		    return null;
+		return new org.gnu.gdk.Color(color);
 	}
 	
 	/**
@@ -232,28 +235,24 @@ public class ColorSelection extends VBox {
 		anEvtMap.addEvent("color_changed", "handleColorChanged", ColorSelectionEvent.Type.COLOR_CHANGED, ColorSelectionListener.class);
 	}
 
-	/****************************************
-     * BEGINNING OF JNI CODE
-     ****************************************/
+
     native static final protected int gtk_color_selection_get_type ();
-    native static final protected int gtk_color_selection_new ();
-    native static final protected boolean gtk_color_selection_get_has_opacity_control (int colorsel);
-    native static final protected void gtk_color_selection_set_has_opacity_control (int colorsel,  boolean hasOpacity);
-    native static final protected boolean gtk_color_selection_get_has_palette (int colorsel);
-    native static final protected void gtk_color_selection_set_has_palette (int colorsel, boolean hasPalette);
-    native static final protected void gtk_color_selection_set_current_color (int colorsel, int color);
-    native static final protected void gtk_color_selection_set_current_alpha (int colorsel, int alpha);
-    native static final protected int gtk_color_selection_get_current_color (int colorsel);
-    native static final protected int gtk_color_selection_get_current_alpha (int colorsel);
-    native static final protected void gtk_color_selection_set_previous_color (int colorsel, int color);
-    native static final protected void gtk_color_selection_set_previous_alpha (int colorsel, int alpha);
-    native static final protected void gtk_color_selection_get_previous_color (int colorsel, int [] color);
-    native static final protected int gtk_color_selection_get_previous_alpha (int colorsel);
-    native static final protected boolean gtk_color_selection_is_adjusting (int colorsel);
-    native static final protected boolean gtk_color_selection_palette_from_string (String str, int [] color, int nColors);
-    native static final protected String gtk_color_selection_palette_to_string (int color, int nColors);
-    /****************************************
-     * END OF JNI CODE
-     ****************************************/
+    native static final protected Handle gtk_color_selection_new ();
+    native static final protected boolean gtk_color_selection_get_has_opacity_control (Handle colorsel);
+    native static final protected void gtk_color_selection_set_has_opacity_control (Handle colorsel,  boolean hasOpacity);
+    native static final protected boolean gtk_color_selection_get_has_palette (Handle colorsel);
+    native static final protected void gtk_color_selection_set_has_palette (Handle colorsel, boolean hasPalette);
+    native static final protected void gtk_color_selection_set_current_color (Handle colorsel, Handle color);
+    native static final protected void gtk_color_selection_set_current_alpha (Handle colorsel, int alpha);
+    native static final protected Handle gtk_color_selection_get_current_color (Handle colorsel);
+    native static final protected int gtk_color_selection_get_current_alpha (Handle colorsel);
+    native static final protected void gtk_color_selection_set_previous_color (Handle colorsel, Handle color);
+    native static final protected void gtk_color_selection_set_previous_alpha (Handle colorsel, int alpha);
+    native static final protected void gtk_color_selection_get_previous_color (Handle colorsel, Handle color);
+    native static final protected int gtk_color_selection_get_previous_alpha (Handle colorsel);
+    native static final protected boolean gtk_color_selection_is_adjusting (Handle colorsel);
+    native static final protected boolean gtk_color_selection_palette_from_string (String str, Handle[] color);
+    native static final protected String gtk_color_selection_palette_to_string (Handle color, int nColors);
+
 }
 
