@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.DialogEvent;
 import org.gnu.gtk.event.DialogListener;
@@ -51,7 +52,7 @@ public class Dialog extends Window {
 	/**
 	 * Construct a dialog using a handle to a native resource.
 	 */
-	public Dialog(int handle) {
+	public Dialog(Handle handle) {
 		super(handle);
 	}
 
@@ -116,7 +117,7 @@ public class Dialog extends Window {
 	 * @return The VBox that is the layout control for the dialog.
 	 */
 	public VBox getDialogLayout() {
-		int hndl = getVbox(getHandle());
+	    Handle hndl = getVbox(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (VBox)obj;
@@ -130,7 +131,7 @@ public class Dialog extends Window {
 	 * @return The HButton box that is known as the action area.
 	 */
 	public HButtonBox getActionArea() {
-		int hndl = Dialog.getActionArea(getHandle());
+	    Handle hndl = Dialog.getActionArea(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj) 
 			return (HButtonBox)obj;
@@ -253,22 +254,18 @@ public class Dialog extends Window {
 		return new Type(gtk_dialog_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
-	native static final protected int getVbox(int cptr);
-	native static final protected int getActionArea(int cptr);
+
+	native static final protected Handle getVbox(Handle cptr);
+	native static final protected Handle getActionArea(Handle cptr);
 	native static final protected int gtk_dialog_get_type();
-	native static final protected int gtk_dialog_new();
-	native static final protected void gtk_dialog_add_action_widget(int dialog, int child, int responseId);
-	native static final protected int gtk_dialog_add_button(int dialog, String buttonText, int responseId);
-	native static final protected void gtk_dialog_set_response_sensitive(int dialog, int responseId, boolean setting);
-	native static final protected void gtk_dialog_set_default_response(int dialog, int responseId);
-	native static final protected void gtk_dialog_set_has_separator(int dialog, boolean setting);
-	native static final protected boolean gtk_dialog_get_has_separator(int dialog);
-	native static final protected void gtk_dialog_response(int dialog, int responseId);
-	native static final protected int gtk_dialog_run(int dialog);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gtk_dialog_new();
+	native static final protected void gtk_dialog_add_action_widget(Handle dialog, Handle child, int responseId);
+	native static final protected Handle gtk_dialog_add_button(Handle dialog, String buttonText, int responseId);
+	native static final protected void gtk_dialog_set_response_sensitive(Handle dialog, int responseId, boolean setting);
+	native static final protected void gtk_dialog_set_default_response(Handle dialog, int responseId);
+	native static final protected void gtk_dialog_set_has_separator(Handle dialog, boolean setting);
+	native static final protected boolean gtk_dialog_get_has_separator(Handle dialog);
+	native static final protected void gtk_dialog_response(Handle dialog, int responseId);
+	native static final protected int gtk_dialog_run(Handle dialog);
+
 }
