@@ -15,6 +15,7 @@ import org.gnu.gdk.Point;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.EntryEvent;
 import org.gnu.gtk.event.EntryListener;
@@ -34,7 +35,7 @@ public class Entry extends Widget implements Editable {
 		super(gtk_entry_new ());
 	}
 	
-	public Entry(int handle) {
+	public Entry(Handle handle) {
 	    super(handle);
 	}
 
@@ -159,7 +160,7 @@ public class Entry extends Widget implements Editable {
 	 * @return The PangoLayout for this entry
 	 */
 	public org.gnu.pango.Layout getLayout(){
-		int hndl = gtk_entry_get_layout(getHandle());
+	    Handle hndl = gtk_entry_get_layout(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (org.gnu.pango.Layout)obj;
@@ -354,7 +355,7 @@ public class Entry extends Widget implements Editable {
 	}
 	
 	public EntryCompletion getCompletion() {
-		int hndl = gtk_entry_get_completion(getHandle());
+	    Handle hndl = gtk_entry_get_completion(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (EntryCompletion)obj;
@@ -417,33 +418,26 @@ public class Entry extends Widget implements Editable {
 	}
 	
 
-	/****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     native static final protected int gtk_entry_get_type ();
-    native static final protected int gtk_entry_new ();
-    native static final protected void gtk_entry_set_visibility (int entry, boolean visible);
-    native static final protected boolean gtk_entry_get_visibility (int entry);
-    native static final protected void gtk_entry_set_invisible_char (int entry, byte ch);
-    native static final protected byte gtk_entry_get_invisible_char (int entry);
-    native static final protected void gtk_entry_set_has_frame (int entry, boolean setting);
-    native static final protected boolean gtk_entry_get_has_frame (int entry);
-    native static final protected void gtk_entry_set_max_length (int entry, int max);
-    native static final protected int gtk_entry_get_max_length (int entry);
-    native static final protected void gtk_entry_set_activates_default (int entry, boolean setting);
-    native static final protected boolean gtk_entry_get_activates_default (int entry);
-    native static final protected void gtk_entry_set_width_chars (int entry, int numChars);
-    native static final protected int gtk_entry_get_width_chars (int entry);
-    native static final protected void gtk_entry_set_text (int entry, String text);
-    native static final protected String gtk_entry_get_text (int entry);
-    native static final protected int gtk_entry_get_layout (int entry);
-    native static final protected void gtk_entry_get_layout_offsets (int entry, int [] x, int [] y);
+    native static final protected Handle gtk_entry_new ();
+    native static final protected void gtk_entry_set_visibility (Handle entry, boolean visible);
+    native static final protected boolean gtk_entry_get_visibility (Handle entry);
+    native static final protected void gtk_entry_set_invisible_char (Handle entry, byte ch);
+    native static final protected byte gtk_entry_get_invisible_char (Handle entry);
+    native static final protected void gtk_entry_set_has_frame (Handle entry, boolean setting);
+    native static final protected boolean gtk_entry_get_has_frame (Handle entry);
+    native static final protected void gtk_entry_set_max_length (Handle entry, int max);
+    native static final protected int gtk_entry_get_max_length (Handle entry);
+    native static final protected void gtk_entry_set_activates_default (Handle entry, boolean setting);
+    native static final protected boolean gtk_entry_get_activates_default (Handle entry);
+    native static final protected void gtk_entry_set_width_chars (Handle entry, int numChars);
+    native static final protected int gtk_entry_get_width_chars (Handle entry);
+    native static final protected void gtk_entry_set_text (Handle entry, String text);
+    native static final protected String gtk_entry_get_text (Handle entry);
+    native static final protected Handle gtk_entry_get_layout (Handle entry);
+    native static final protected void gtk_entry_get_layout_offsets (Handle entry, int [] x, int [] y);
+    native static final protected void gtk_entry_set_completion(Handle entry, Handle completion);
+    native static final protected Handle gtk_entry_get_completion(Handle entry);
 
-    // new methods for 2.5.1
-    native static final protected void gtk_entry_set_completion(int entry, int completion);
-    native static final protected int gtk_entry_get_completion(int entry);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
 }
 
