@@ -10,6 +10,7 @@
 package org.gnu.gtk;
 
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 
 /**
  */
@@ -27,7 +28,7 @@ public class FileFilter extends GObject {
 	/**
 	 * Create a new FileFilter from a point to a native object.
 	 */
-	FileFilter(int hndl) {
+	FileFilter(Handle hndl) {
 		super(hndl);
 	}
 	
@@ -62,18 +63,15 @@ public class FileFilter extends GObject {
 		gtk_file_filter_add_pattern(getHandle(), pattern);
 	}
 	
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
+
 	native static final protected int gtk_file_filter_get_type ();
-	native static final protected int gtk_file_filter_new();
-	native static final protected void gtk_file_filter_set_name(int filter, String name);
-	native static final protected String gtk_file_filter_get_name(int filter);
-	native static final protected void gtk_file_filter_add_mime_type(int filter, String mimeType);
-	native static final protected void gtk_file_filter_add_pattern(int filter, String pattern);
-	native static final protected int gtk_file_filter_get_needed(int filter);
-	native static final protected boolean gtk_file_filter_filter(int filter, int filterInfo);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected Handle gtk_file_filter_new();
+	native static final protected void gtk_file_filter_set_name(Handle filter, String name);
+	native static final protected String gtk_file_filter_get_name(Handle filter);
+	native static final protected void gtk_file_filter_add_mime_type(Handle filter, String mimeType);
+	native static final protected void gtk_file_filter_add_pattern(Handle filter, String pattern);
+	native static final protected int gtk_file_filter_get_needed(Handle filter);
+	// We currently do not have a wrapper for FileFilterInfo.
+	//native static final protected boolean gtk_file_filter_filter(Handle filter, int filterInfo);
+
 }
