@@ -9,6 +9,7 @@
 
 package org.gnu.gtk;
 
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
 /**
@@ -26,7 +27,7 @@ public class GammaCurve extends VBox
 	/**
 	 * Construct a new GammaCurve from a handle to a native resource.
 	 */
-	public GammaCurve(int handle) {
+	public GammaCurve(Handle handle) {
 	    super(handle);
 	}
 	
@@ -41,18 +42,12 @@ public class GammaCurve extends VBox
 		return new Type(gtk_gamma_curve_get_type());
 	}
 
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
-    native static final protected int getTable (int cptr);
-    native static final protected int getCurve (int cptr);
-    native static final protected double getGamma (int cptr);
-    native static final protected int getGammaDialog (int cptr);
-    native static final protected int getGammaText (int cptr);
+    native static final protected int getTable (Handle cptr);
+    native static final protected int getCurve (Handle cptr);
+    native static final protected double getGamma (Handle cptr);
+    native static final protected int getGammaDialog (Handle cptr);
+    native static final protected int getGammaText (Handle cptr);
     native static final protected int gtk_gamma_curve_get_type ();
-    native static final protected int gtk_gamma_curve_new ();
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+    native static final protected Handle gtk_gamma_curve_new ();
 }
 
