@@ -9,6 +9,7 @@
 
 package org.gnu.gtk;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  * You may wish to begin by reading the {@link TextView} overview which gives an
@@ -31,7 +32,7 @@ public class TextMark extends GObject
 {
 	/**
 	 */
-	protected TextMark(int handle){
+	protected TextMark(Handle handle){
 		super(handle);
 	}
 
@@ -78,7 +79,7 @@ public class TextMark extends GObject
 	 * @return The buffer/
 	 */
 	public TextBuffer getBuffer(){
-		int hndl = gtk_text_mark_get_buffer(getHandle());
+	    Handle hndl = gtk_text_mark_get_buffer(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (TextBuffer)obj;
@@ -100,18 +101,12 @@ public class TextMark extends GObject
 		return new Type(gtk_text_mark_get_type());
 	}
 
-	/****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     native static final protected int gtk_text_mark_get_type ();
-    native static final protected void gtk_text_mark_set_visible (int mark, boolean setting);
-    native static final protected boolean gtk_text_mark_get_visible (int mark);
-    native static final protected String gtk_text_mark_get_name (int mark);
-    native static final protected boolean gtk_text_mark_get_deleted (int mark);
-    native static final protected int gtk_text_mark_get_buffer (int mark);
-    native static final protected boolean gtk_text_mark_get_left_gravity (int mark);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+    native static final protected void gtk_text_mark_set_visible (Handle mark, boolean setting);
+    native static final protected boolean gtk_text_mark_get_visible (Handle mark);
+    native static final protected String gtk_text_mark_get_name (Handle mark);
+    native static final protected boolean gtk_text_mark_get_deleted (Handle mark);
+    native static final protected Handle gtk_text_mark_get_buffer (Handle mark);
+    native static final protected boolean gtk_text_mark_get_left_gravity (Handle mark);
 }
 
