@@ -25,7 +25,7 @@ import org.gnu.glib.Value;
  *
  * @author Mark Howard &lt;mh@debian.org&gt;
  */
-public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource {
+public class TreeStore extends TreeModel implements TreeSortable, TreeDragDest, TreeDragSource {
 	/**
 	 * Constructs a new TreeStore, defining the types for each datablock.
 	 * Subsequent setting of data to any of the datablocks must follow the types
@@ -62,7 +62,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data
 	 * @param iter Valid iterator for the data row in which the value is to be
@@ -83,7 +83,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data
 	 * @param iter Valid iterator for the data row in which the value is to be
@@ -104,7 +104,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data
 	 * @param iter Valid iterator for the data row in which the value is to be
@@ -125,7 +125,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data
 	 * @param iter Valid iterator for the data row in which the value is to be
@@ -146,7 +146,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data
 	 * @param iter Valid iterator for the data row in which the value is to be
@@ -166,7 +166,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data
 	 * @param iter Valid iterator for the data row in which the value is to be
@@ -187,7 +187,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data, starting at
 	 * 0.
@@ -210,7 +210,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * {@link TreeView}; construct and add a {@link CellRenderer} to that; and
 	 * finally associate the properties of the CellRenderer with the dataBlocks,
 	 * using the {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
-	 * DataColumn)} method.  @param dataBlock The datablock in which the data should be
+	 * int)} method.  @param dataBlock The datablock in which the data should be
 	 * stored.
 	 * @param dataBlock The data block in which to store the data, starting at
 	 * 0.
@@ -228,7 +228,7 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	 * Removes a row from the tree store. After being removed, iter is set to
 	 * the next valid row at that level, or invalidated if it previously pointed
 	 * to the last one.
-	 * @param iter TreeIter representing the row.
+	 * @paramTreeIter iterator representing the row.
 	 */
 	public void removeRow(TreeIter iter) {
 		gtk_tree_store_remove(getHandle(), iter.getHandle());
@@ -345,6 +345,65 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 		return new Type(gtk_tree_store_get_type());
 	}
 
+	// 
+	// TreeSortable interface.
+	//
+
+	/**
+	 * Set the column in the list to sort on.
+	 */
+	public void setSortColumn( DataColumn column, SortType order ) {
+		TreeSortableHelper.setSortColumn( this, column, order );
+	}
+
+	/**
+	 * Get a DataColumn object representing the currently sorted column.  This
+	 * is not the same DataColumn used to create the store.  It is only of type
+	 * DataColumn (not DataColumnString, etc).  It can be compared with another
+	 * DataColumn object using the <tt>{@link DataColumn#equals}</tt> method.
+	 *
+	 * @return A DataColumn object representing the currently sorted column or
+	 * <tt>null</tt> if there is no column currently sorted.
+	 */
+	public DataColumn getSortColumn() {
+		return TreeSortableHelper.getSortColumn( this );
+	}
+
+	/**
+	 * Get the current sorting order of the store.
+	 *
+	 * @return A SortType object defining the current sorting order of the 
+	 * store or <tt>null</tt> if there is no current sort order.
+	 */
+	public SortType getSortOrder() {
+		return TreeSortableHelper.getSortOrder( this );
+	}
+
+	/**
+	 * Set the class used to sort the list according to the values stored
+	 * in the given DataColumn.
+	 */
+	public void setSortMethod( TreeIterComparison method, DataColumn column ) {
+		TreeSortableHelper.setSortMethod( this, method, column );
+	}
+
+	/**
+	 * Call-back method invoked by the JNI code when sorting is required.  This
+	 * is for internal use only.
+	 */
+	public int handleCompareFunc( Handle model, Handle aIter, 
+				      Handle bIter, int col ) {
+		TreeIterComparison method = TreeSortableHelper.getMethod( this, col );
+		if ( method != null ) {
+			TreeModel mdl = (TreeModel)retrieveGObject( model );
+			TreeIter a = new TreeIter( aIter, mdl );
+			TreeIter b = new TreeIter( bIter, mdl );
+			return method.compareTreeIters( mdl, a, b );
+		} else {
+			return 0;
+		}
+	}
+
 	public void setDragDestListener( TreeDragDestListener listener ){
 		// TODO
 		throw new RuntimeException("Not yet implemented");
@@ -375,10 +434,9 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	}
 
 	/**
-	 * Moves iter in this store to the position after
-	 * position. <tt>iter</tt> and <tt>position</tt> should be in
-	 * the same level. Note that this function only works with
-	 * unsorted stores.
+	 * Moves iter in this store to the position after position. iter and
+	 * position should be in the same level. Note that this function only works
+	 * with unsorted stores.
 	 *
 	 * @since 2.2
 	 */
@@ -396,10 +454,9 @@ public class TreeStore extends TreeModel implements TreeDragDest, TreeDragSource
 	}
 
 	/**
-	 * Moves iter in tree_store to the position before
-	 * position. <tt>iter</tt> and <tt>position</tt> should be in
-	 * the same level. Note that this function only works with
-	 * unsorted stores.
+	 * Moves iter in tree_store to the position before position. iter and
+	 * position should be in the same level. Note that this function only works
+	 * with unsorted stores.
 	 *
 	 * @since 2.2
 	 */
